=============
NLP_in_Action
=============


Add a short description here!


Description
===========

A LONGER DESCRIPTION OF YOUR PROJECT GOES HERE...


Note
====

This project has been set up using PyScaffold 2.5.6. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
